@@ -8,7 +8,7 @@ PYTHON_CLIENT_ID = "beneath-python"
 DEFAULT_READ_BATCH_SIZE = 1000
 DEFAULT_READ_ALL_MAX_BYTES = 10 * 2**20
 DEFAULT_WRITE_DELAY_MS = 1000
-DEFAULT_WRITE_PIPELINE_STATE_DELAY_MS = 30000
+DEFAULT_WRITE_PIPELINE_CHECKPOINT_DELAY_MS = 30000
 DEFAULT_SUBSCRIBE_POLL_AT_LEAST_EVERY_MS = 60000
 DEFAULT_SUBSCRIBE_POLL_AT_MOST_EVERY_MS = 1000
 DEFAULT_QUERY_WAREHOUSE_TIMEOUT_MS = 60 * 1000
